@@ -23,7 +23,7 @@
 
 from datetime import datetime
 from ipaddress import ip_address
-from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, Tuple, Union
 
 import pytest
 from pytest import raises
@@ -41,6 +41,7 @@ from elasticsearch.dsl import (
     Ip,
     Keyword,
     Long,
+    M,
     Mapping,
     MetaField,
     Nested,
@@ -52,6 +53,8 @@ from elasticsearch.dsl import (
     analyzer,
     mapped_field,
 )
+from elasticsearch.dsl.query import Match
+from elasticsearch.dsl.types import MatchQuery
 from elasticsearch.dsl.utils import AttrList
 from elasticsearch.helpers.errors import BulkIndexError
 
@@ -842,3 +845,47 @@ def test_dense_vector(client: Elasticsearch, es_version: Tuple[int, ...]) -> Non
     assert docs[0].float_vector == doc.float_vector
     assert docs[0].byte_vector == doc.byte_vector
     assert docs[0].bit_vector == doc.bit_vector
+
+
+@pytest.mark.sync
+def test_copy_to(client: Elasticsearch) -> None:
+    class Person(Document):
+        first_name: M[str] = mapped_field(Text(copy_to=["full_name", "all"]))
+        last_name: M[str] = mapped_field(Text(copy_to=["full_name", "all"]))
+        birth_place: M[str] = mapped_field(Text(copy_to="all"))
+        full_name: M[Optional[str]] = mapped_field(init=False)
+        all: M[Optional[str]] = mapped_field(init=False)
+
+        class Index:
+            name = "people"
+
+    Person._index.delete(ignore_unavailable=True)
+    Person.init()
+
+    person = Person(first_name="Jane", last_name="Doe", birth_place="Springfield")
+    person.save()
+    Person._index.refresh()
+
+    match = (
+        Person.search()
+        .query(Match(Person.full_name, MatchQuery(query="Jane")))
+        .execute()
+    )
+    assert len(match) == 1
+
+    match = Person.search().query(Match(Person.all, MatchQuery(query="Doe"))).execute()
+    assert len(match) == 1
+
+    match = (
+        Person.search()
+        .query(Match(Person.full_name, MatchQuery(query="Springfield")))
+        .execute()
+    )
+    assert len(match) == 0
+
+    match = (
+        Person.search()
+        .query(Match(Person.all, MatchQuery(query="Springfield")))
+        .execute()
+    )
+    assert len(match) == 1
